@@ -14,7 +14,11 @@ from xlsx_lib.domain.xlsx_elements.sheet import Sheet
 
 def get_abs_cell_value_kind(cell: Cell) -> AbsCellValueKind:
     if cell.font.b and cell.alignment.horizontal == "center" and cell.value is not None:
-        if len(re.search("(CODIGO)", str(cell.value).upper()).groups()) > 0:
+        search_result = re.search("(CODIGO)", str(cell.value).upper())
+
+        result_count = len(search_result.groups()) if search_result is not None else 0
+
+        if result_count > 0:
             return AbsCellValueKind.CODE_COLUMN_TITLE
         else:
             raise ContinueException
